.. _functions:

Functions
=========

.. module:: nani
   :noindex:

.. autosummary::
   :nosignatures:

   resolve
   update
   get_data
   get_element_view


.. autofunction:: resolve
.. autofunction:: update
.. autofunction:: get_data
.. autofunction:: get_element_view
